// model-header.mustache

// licenseInfo.mustache

/**
 * Libre Graph API
 * Libre Graph is a free API for cloud collaboration inspired by the MS Graph API.
 *
 * The version of the OpenAPI document: v1.0.4
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */

/*
 * OAIApplication.h
 *
 * 
 */

#ifndef OAIApplication_H
#define OAIApplication_H

#include <QJsonObject>

#include "OAIAppRole.h"
#include <QList>
#include <QString>

#include "OAIEnum.h"
#include "OAIObject.h"

namespace OpenAPI {
class OAIAppRole;


class OAIApplicationPrivate;

class OAIApplication : public OAIObject {
public:
    OAIApplication();
    OAIApplication(const OAIApplication &other);
    OAIApplication(QString json);
    ~OAIApplication() override;

    QString asJson() const override;
    QJsonObject asJsonObject() const override;
    void fromJsonObject(QJsonObject json) override;
    void fromJson(QString jsonString) override;

    QString getId() const;
    void setId(const QString &id);
    bool is_id_Set() const;
    bool is_id_Valid() const;

    QList<OAIAppRole> getAppRoles() const;
    void setAppRoles(const QList<OAIAppRole> &app_roles);
    bool is_app_roles_Set() const;
    bool is_app_roles_Valid() const;

    QString getDisplayName() const;
    void setDisplayName(const QString &display_name);
    bool is_display_name_Set() const;
    bool is_display_name_Valid() const;

    virtual bool isSet() const override;
    virtual bool isValid() const override;

private:
    void initializeModel();
    Q_DECLARE_PRIVATE(OAIApplication)
    QSharedPointer<OAIApplicationPrivate> d_ptr;
};

} // namespace OpenAPI

Q_DECLARE_METATYPE(OpenAPI::OAIApplication)

#endif // OAIApplication_H
